1.0 (2020-09-18)
----------------

- Official release.


0.1 (2020-08-26)
----------------

- Initial release.


..
    Below is a template for the sections used in release changes.

    New Features
    ^^^^^^^^^^^^

    Bug Fixes
    ^^^^^^^^^

    Other Changes and Additions
    ^^^^^^^^^^^^^^^^^^^^^^^^^^^
